@@ -133,6 +133,16 @@ class Gfx(Component):
         self._data[4] = x
         self._data[5] = y
         self._writeToFS = True
+    def moveX(self, dx):
+        self._data[4] += dx
+        self._writeToFS = True
+    def moveY(self, dy):
+        self._data[5] += dy
+        self._writeToFS = True
+    def movePosition(self, dx, dy):
+        self._data[4] += dx
+        self._data[5] += dy
+        self._writeToFS = True
     def setTransform(self, x, y, ang):
         self._data[4] = x
         self._data[5] = y
@@ -329,7 +339,7 @@ class GfxSprite(Gfx):
         textureID = texture["id"]
         w         = texture["w"]
         h         = texture["h"]
-        print(f"Load GfxSprite : {textureID}-{textureName}-?-?-{w}-{h}")
+        # print(f"Load GfxSprite : {textureID}-{textureName}-?-?-{w}-{h}")
         # if width or height is not filled, use the texture dimensions
         if width > 0:
             w = width
@@ -355,7 +365,7 @@ class GfxSprite(Gfx):
                          dataSize=NB_VALUES,
                          gfxType=Gfx.TYPE_SPRITE,
                          blockID=self._blockID,
-                         name=name)
+                         name=name+'_'+textureName)
 
         # Store specific information for this Sprite
         self.setTextureID(textureID)
